@@ -4,9 +4,9 @@
  * GChemPaint
  * gchempaint-bonobo.cc 
  *
- * Copyright (C) 2001-2005
+ * Copyright (C) 2001-2003
  *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,13 +24,13 @@
  * USA
  */
 
-#include "config.h"
+#include "gchempaint-config.h"
 #include "gchempaint-bonobo.h"
-#include "file.h"
-#include "filesel.h"
-#include "tools.h"
-#include "mendeleiev.h"
+#include "lib/view.h"
+#include "lib/widgetdata.h"
+#include "bonoboapp.h"
 #include <libgnome/libgnome.h>
+#include <stdlib.h>
 
 extern int CurElt;
 
@@ -212,22 +212,21 @@ static GObjectClass *gcp_bonobo_control_parent_class;
 static void
 gcp_bonobo_control_destroy (BonoboObject *object)
 {
-	gcpBonoboControl *control;
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GCP_BONOBO_IS_CONTROL (object));
-
-	control = GCP_BONOBO_CONTROL (object);
 	BONOBO_OBJECT_CLASS (gcp_bonobo_control_parent_class)->destroy (object);
-	delete control->ps->pDoc;
 }
 
 static void
 gcp_bonobo_control_finalize (GObject *object)
 {
+	gcpBonoboControl *control;
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GCP_BONOBO_IS_CONTROL (object));
 
+	control = GCP_BONOBO_CONTROL (object);
 	G_OBJECT_CLASS (gcp_bonobo_control_parent_class)->finalize (object);
+	delete control->ps->pDoc;
 }
 
 void gcp_bonobo_set_state(gpointer data, const char *id, const char *state)
@@ -236,11 +235,12 @@ void gcp_bonobo_set_state(gpointer data, const char *id, const char *state)
 	for (i = ActiveControls.begin(); i != ActiveControls.end(); i++)
 		if (*i != data)
 			bonobo_ui_component_set_prop((*i)->uic, id, "state", state, NULL);
-	if ((!strcmp(id, "/commands/ViewTools")) && (!strcmp(state, "0")) && pActiveTool)
+#warning "FIXME: use data to get active tool"
+/*	if ((!strcmp(id, "/commands/ViewTools")) && (!strcmp(state, "0")) && pActiveTool)
 	{
 		pActiveTool->Deactivate();
 		pActiveTool = NULL;
-	}
+	}*/
 }
 
 extern void on_file_save_as(GtkWidget* widget, void* data);
@@ -249,7 +249,8 @@ static void
 on_save_as_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
 	gcpBonoboControl *control = GCP_BONOBO_CONTROL(user_data);
-	on_file_save_as(NULL, control->ps->pDoc);
+	gcpApplication *App = control->ps->pDoc->GetApplication ();
+	App->OnSaveAs ();
 }
 
 extern void on_print(GtkWidget* widget, void* data);
@@ -258,7 +259,7 @@ static void
 on_print_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
 	gcpBonoboControl *control = GCP_BONOBO_CONTROL(user_data);
-	on_print(NULL, control->ps->pDoc);
+//	on_print(NULL, control->ps->pDoc);
 }
 
 static void
@@ -339,7 +340,7 @@ static void ui_event_handler (BonoboUIComponent *component, const char *id,
                                   Bonobo_UIComponent_EventType  type,  const char *state,
                                   gpointer user_data)
 {
-	if (!strcmp(id, "ViewTools"))
+/*	if (!strcmp(id, "ViewTools"))
 	{
 		if ((*state == '1') ^ (ToolsDlg != NULL))
 		{
@@ -364,7 +365,7 @@ static void ui_event_handler (BonoboUIComponent *component, const char *id,
 			}
 			gcp_bonobo_set_state(user_data, "/commands/ViewElements", state);
 		}
-	}
+	}*/
 }
 
 static BonoboUIVerb gcp_verbs[] = {
@@ -407,11 +408,10 @@ gcp_bonobo_control_activate (BonoboControl *object, gboolean state)
 			g_signal_connect(control->uic, "ui-event", G_CALLBACK(ui_event_handler), control);
 			if (bonobo_ui_component_get_container(control->uic) != CORBA_OBJECT_NIL)
 			{
-				if (ToolsDlg)
-					bonobo_ui_component_set_prop(control->uic, "/commands/ViewTools", "state", "1", NULL);
-				if (MendeleievDlg)
+//				if (MendeleievDlg)
 					bonobo_ui_component_set_prop(control->uic, "/commands/ViewElements", "state", "1", NULL);
-					bonobo_ui_component_set_prop(control->uic, "/menu/Help/BuiltMenuItems/Helpgchempaint0", "label", _("GChemPaint help contents"), NULL);
+				
+				bonobo_ui_component_set_prop(control->uic, "/menu/Help/BuiltMenuItems/Helpgchempaint0", "label", _("GChemPaint help contents"), NULL);
 				bonobo_ui_component_set_prop(control->uic, "/menu/Help/BuiltMenuItems/Helpgchempaint0", "tip", _("View help for GChemPaint"), NULL);
 				ActiveControls.push_front(control);
 			}
@@ -451,6 +451,7 @@ gcpBonoboControl* gcp_bonobo_control_construct(gcpBonoboControl *control, gcpDoc
 {
 	GtkWidget             *widget;
 	BonoboPropertyBag     *pb;
+	BonoboPropertyControl *pc;
 	CORBA_Environment ev;
 	
 	g_return_val_if_fail (pDoc != NULL, NULL);
@@ -506,7 +507,8 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 	g_return_val_if_fail (component_id != NULL, NULL);
 
 	BonoboObject *retval;
-	gcpDocument* pDoc =  new gcpDocument();
+	gcpBonoboApp* App = new gcpBonoboApp();
+	gcpDocument* pDoc =  new gcpDocument(App, false);
 	if (!pDoc) return NULL;
 	if (!strcmp (component_id, "OAFIID:gchempaint_control"))
 	{
@@ -527,3 +529,7 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 
 	return retval;
 }
+
+int main (int argc, char *argv[])
+{
+}
